experimental_lowqa package — docs

Skip to main content
`Ctrl`+`K`

# experimental_lowqa package

## Subpackages

- experimental_lowqa.tasks package
  - Subpackages
    - experimental_lowqa.tasks.yambs package
      - Subpackages
      - Submodules
      - experimental_lowqa.tasks.yambs.common module
      - experimental_lowqa.tasks.yambs.gcov module
      - experimental_lowqa.tasks.yambs.udev module
      - Module contents
  - Submodules
  - experimental_lowqa.tasks.conntextual module
    - `ConntextualTask`
      - `ConntextualTask.default_requirements`
      - `ConntextualTask.run()`
    - `register()`
  - experimental_lowqa.tasks.docs module
    - `SphinxTask`
      - `SphinxTask.default_requirements`
      - `SphinxTask.run()`
  - experimental_lowqa.tasks.python module
    - `PythonTags`
      - `PythonTags.extra_source_candidates`
      - `PythonTags.languages`
      - `PythonTags.run()`
    - `to_slug()`
  - experimental_lowqa.tasks.runtimepy module
    - `ArbiterTask`
      - `ArbiterTask.default_requirements`
      - `ArbiterTask.run()`
  - Module contents

## Submodules

## experimental_lowqa.edit module

A module implementing a target for preparing tags for editing.

class experimental_lowqa.edit.GenerateTags(name: str, *args, execute: Callable[[dict[str, dict[str, Any]], dict[str, Any]], Coroutine[Any, Any, bool]] = None, log: Logger = None, timer: Timer = None, target: Target = None, **kwargs)

  Bases: `SubprocessLogMixin`

  A class implementing a task for generating tags files.

  default_editor = 'vim'
  extra_excludes: list[tuple[str, ...]] = []
  extra_source_candidates: list[tuple[str | Path, ...]] = [('pico-sdk', 'src', 'boards'), ('pico-sdk', 'src', 'common'), ('pico-sdk', 'src', 'rp2_common'), ('pico-sdk', 'src', 'rp2040'), ('RP2040-HAT-C',), ('ioLibrary_Driver', 'Ethernet'), ('ioLibrary_Driver', 'Internet', 'DHCP'), ('ioLibrary_Driver', 'Internet', 'DNS')]
  languages = 'C,C++'
  async run(inbox: dict[str, dict[str, Any]], outbox: dict[str, Any], *args, **kwargs) → bool

    Generate a tags files.

experimental_lowqa.edit.is_local_bin(program: str) → bool

  Determine if a binary or entry script is installed locally.

experimental_lowqa.edit.local_bin(program: str) → Path

  Get the path to a local binary.

experimental_lowqa.edit.local_bin_if(program: str) → str

  Prefer a local binary instead if it exists.

## experimental_lowqa.env module

A module for working with environment variables.

experimental_lowqa.env.real_sources(root: Path, candidates: Iterable[tuple[str | Path, ...]]) → Iterator[Path]

  Add extra source directories that may be used.

experimental_lowqa.env.source_file(path: Path) → None

  Attempt to source a file.

experimental_lowqa.env.try_source(path: Path) → None

  Attempt to source a file if it exists.

## experimental_lowqa.prompts module

A module implementing interfaces for prompting the user for input.

class experimental_lowqa.prompts.SelectOpts(default: str = '', allow_prompt: bool = True, custom_option: bool = False, descriptions: Dict[str, str] | None = None, prompt: str = 'selection? ')

  Bases: `NamedTuple`

  Manual select method options.

  allow_prompt: bool

    Alias for field number 1

  custom_option: bool

    Alias for field number 2

  default: str

    Alias for field number 0

  descriptions: Dict[str, str] | None

    Alias for field number 3

  prompt: str

    Alias for field number 4

async experimental_lowqa.prompts.async_boolean_select(label: str, **kwargs) → bool

  Provide a boolean select prompt.

async experimental_lowqa.prompts.async_manual_select(label: str, options: Iterable[str], **kwargs) → str | None

  Prompt the user until an option from the provided set of options is chosen.

experimental_lowqa.prompts.boolean_select(label: str, **kwargs) → bool

  Provide a boolean select prompt.

experimental_lowqa.prompts.manual_select(label: str, options: Iterable[str], **kwargs) → str | None

  Prompt the user until an option from the provided set of options is chosen.

experimental_lowqa.prompts.select_option(options: Iterable[str], prompt: str = 'selection? ', print_options: bool = False) → int | None

  Given a list of options, prompt user until they select a valid index and return it.

## experimental_lowqa.userfs module

Common methods and definitions for project hooks.

experimental_lowqa.userfs.link_local_bin(path: Path) → None

  Link a local binary from some arbitrary location.

## Module contents

Useful defaults and other package metadata.